@@ -6,7 +6,10 @@ use crate::client::Client;
 use crate::api::{API, Futures};
 use crate::model::Empty;
 use crate::account::{OrderSide, TimeInForce};
-use super::model::{ChangeLeverageResponse, Transaction, CanceledOrder, Position, AccountBalance};
+use super::model::{
+    ChangeLeverageResponse, Transaction, CanceledOrder, PositionRisk, AccountBalance,
+    AccountInformation,
+};
 
 #[derive(Clone)]
 pub struct FuturesAccount {
@@ -244,6 +247,19 @@ impl FuturesAccount {
             .delete_signed(API::Futures(Futures::Order), Some(request))
     }
 
+    pub fn cancel_order_with_client_id<S>(&self, symbol: S, orig_client_order_id: String) -> Result<CanceledOrder>
+    where
+        S: Into<String>,
+    {
+        let mut parameters = BTreeMap::new();
+        parameters.insert("symbol".into(), symbol.into());
+        parameters.insert("origClientOrderId".into(), orig_client_order_id);
+
+        let request = build_signed_request(parameters, self.recv_window)?;
+        self.client
+            .delete_signed(API::Futures(Futures::Order), Some(request))
+    }
+
     // Place a STOP_MARKET close - BUY
     pub fn stop_market_close_buy<S, F>(&self, symbol: S, stop_price: F) -> Result<Transaction>
     where
@@ -373,7 +389,7 @@ impl FuturesAccount {
         parameters
     }
 
-    pub fn position_information<S>(&self, symbol: S) -> Result<Vec<Position>>
+    pub fn position_information<S>(&self, symbol: S) -> Result<Vec<PositionRisk>>
     where
         S: Into<String>,
     {
@@ -385,6 +401,14 @@ impl FuturesAccount {
             .get_signed(API::Futures(Futures::PositionRisk), Some(request))
     }
 
+    pub fn account_information(&self) -> Result<AccountInformation> {
+        let parameters = BTreeMap::new();
+
+        let request = build_signed_request(parameters, self.recv_window)?;
+        self.client
+            .get_signed(API::Futures(Futures::Account), Some(request))
+    }
+
     pub fn account_balance(&self) -> Result<Vec<AccountBalance>> {
         let parameters = BTreeMap::new();
 
