@@ -6,6 +6,7 @@ use std::collections::BTreeMap;
 use serde_json::Value;
 use crate::api::API;
 use crate::api::Spot;
+use std::convert::TryInto;
 
 #[derive(Clone)]
 pub struct Market {
@@ -169,21 +170,10 @@ impl Market {
 
         let klines = KlineSummaries::AllKlineSummaries(
             data.iter()
-                .map(|row| KlineSummary {
-                    open_time: to_i64(&row[0]),
-                    open: to_f64(&row[1]),
-                    high: to_f64(&row[2]),
-                    low: to_f64(&row[3]),
-                    close: to_f64(&row[4]),
-                    volume: to_f64(&row[5]),
-                    close_time: to_i64(&row[6]),
-                    quote_asset_volume: to_f64(&row[7]),
-                    number_of_trades: to_i64(&row[8]),
-                    taker_buy_base_asset_volume: to_f64(&row[9]),
-                    taker_buy_quote_asset_volume: to_f64(&row[10]),
-                })
-                .collect(),
+                .map(|row| row.try_into())
+                .collect::<Result<Vec<KlineSummary>>>()?,
         );
+
         Ok(klines)
     }
 }
